==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ca.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saved" : "Desat",
    "Saving failed:" : "Error al desar",
    "File MIME type" : "Tipus MIME d\\'arxiu",
    "is" : "és",
    "is not" : "no és",
    "matches" : "coincidències",
    "does not match" : "No hi ha coincidències",
    "Example: {placeholder}" : "Exemple: {placeholder}",
    "File size (upload)" : "Mida d\\'arxiu (pujar)",
    "less" : "menys",
    "less or equals" : "menor o igual",
    "greater or equals" : "major o igual",
    "greater" : "superior",
    "File system tag" : "Etiqueta del sistema de fitxers",
    "is tagged with" : "està estiquetat amb",
    "is not tagged with" : "no està etiquetat amb",
    "Select tag…" : "Selecciona etiqueta...",
    "Request remote address" : "Demanar adreça remota",
    "matches IPv4" : "coincidències IPv4",
    "does not match IPv4" : "No hi ha coincidencies IPv4",
    "matches IPv6" : "Coincidències IPv6",
    "does not match IPv6" : "No hi ha coincidències IPv6",
    "Request time" : "Temps d'espera",
    "between" : "entre",
    "not between" : "no entre",
    "Start" : "Comença",
    "End" : "Finalitza",
    "Select timezone…" : "Selecciona zona horaria",
    "Request URL" : "URL de la petició",
    "Predefined URLs" : "URLs predefinits",
    "Files WebDAV" : "Arxius WebDAV",
    "Request user agent" : "Agent d\\'usuari de la petició",
    "Sync clients" : "Sincronitzar clients",
    "Android client" : "Client android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client d'escriptori",
    "User group membership" : "Pertinença a grup d'usuaris",
    "is member of" : "és membre de",
    "is not member of" : "no és membre de",
    "The given operator is invalid" : "L\\'operador donat no és vàlid",
    "The given regular expression is invalid" : "L\\'expresió regular donada no és vàlida",
    "The given file size is invalid" : "El tamany de fitxer donat no és vàlid",
    "The given tag id is invalid" : "L\\'Id d'etiqueta donat no és vàlid",
    "The given IP range is invalid" : "El rang d\\'IPs donat no és vàlid",
    "The given IP range is not valid for IPv4" : "El rang d\\'IP donat no és vàlid per IPv4",
    "The given IP range is not valid for IPv6" : "El rang d\\'IP donat no és vàlid per IPv6",
    "The given time span is invalid" : "El rang de temps donat no és vàlid",
    "The given start time is invalid" : "El temps d\\'inici donat no és vàlid",
    "The given end time is invalid" : "El temps de finalització donat no és vàlid",
    "The given group does not exist" : "El grup donat no existeix",
    "Check %s is invalid or does not exist" : "Comprovació %s no és vàlida o no existeix",
    "Operation #%s does not exist" : "L\\'operació #%s no existeix",
    "Operation %s does not exist" : "L\\'operació %s no existeix",
    "Operation %s is invalid" : "L\\'operació %s no és vàlida",
    "Check %s does not exist" : "Comprovació %s no existeix",
    "Check %s is invalid" : "Comprovació %s no és vàlid",
    "Check #%s does not exist" : "Comprovació #%s no existeix",
    "Workflow" : "Flux de treball",
    "Open documentation" : "Obrir documentació",
    "Add rule group" : "Afegeix una regla de grup",
    "Short rule description" : "Descripció breu de regla",
    "Add rule" : "Afegir regla",
    "Reset" : "Resetejar",
    "Save" : "Desa",
    "Saving…" : "Desant...",
    "Loading…" : "Carregant..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ca.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Descripció breu de regla",
    "Add rule" : "Afegir regla",
    "Reset" : "Resetejar",
    "Save" : "Desa",
    "Saving…" : "Desant...",
    "Group list is empty" : "La llista del grup és buida",
    "Unable to retrieve the group list" : "No es pot obtenir la llista del grup",
    "Saved" : "Desat",
    "Saving failed:" : "Error al desar",
    "Add rule group" : "Afegeix una regla de grup",
    "File MIME type" : "Tipus MIME d\\'arxiu",
    "is" : "és",
    "is not" : "no és",
    "matches" : "coincidències",
    "does not match" : "No hi ha coincidències",
    "Example: {placeholder}" : "Exemple: {placeholder}",
    "File size (upload)" : "Mida d\\'arxiu (pujar)",
    "less" : "menys",
    "less or equals" : "menor o igual",
    "greater or equals" : "major o igual",
    "greater" : "superior",
    "File system tag" : "Etiqueta del sistema de fitxers",
    "is tagged with" : "està estiquetat amb",
    "is not tagged with" : "no està etiquetat amb",
    "Select tag…" : "Selecciona etiqueta...",
    "Request remote address" : "Demanar adreça remota",
    "matches IPv4" : "coincidències IPv4",
    "does not match IPv4" : "No hi ha coincidencies IPv4",
    "matches IPv6" : "Coincidències IPv6",
    "does not match IPv6" : "No hi ha coincidències IPv6",
    "Request time" : "Temps d'espera",
    "between" : "entre",
    "not between" : "no entre",
    "Start" : "Comença",
    "End" : "Finalitza",
    "Select timezone…" : "Selecciona zona horaria",
    "Request URL" : "URL de la petició",
    "Predefined URLs" : "URLs predefinits",
    "Files WebDAV" : "Arxius WebDAV",
    "Request user agent" : "Agent d\\'usuari de la petició",
    "Sync clients" : "Aplicacions per sincronitzar",
    "Android client" : "Client android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client d'escriptori",
    "User group membership" : "Pertinença a grup d'usuaris",
    "is member of" : "és membre de",
    "is not member of" : "no és membre de",
    "The given operator is invalid" : "L\\'operador donat no és vàlid",
    "The given regular expression is invalid" : "L\\'expresió regular donada no és vàlida",
    "The given file size is invalid" : "El tamany de fitxer donat no és vàlid",
    "The given tag id is invalid" : "L\\'Id d'etiqueta donat no és vàlid",
    "The given IP range is invalid" : "El rang d\\'IPs donat no és vàlid",
    "The given IP range is not valid for IPv4" : "El rang d\\'IP donat no és vàlid per IPv4",
    "The given IP range is not valid for IPv6" : "El rang d\\'IP donat no és vàlid per IPv6",
    "The given time span is invalid" : "El rang de temps donat no és vàlid",
    "The given start time is invalid" : "El temps d\\'inici donat no és vàlid",
    "The given end time is invalid" : "El temps de finalització donat no és vàlid",
    "The given group does not exist" : "El grup donat no existeix",
    "Check %s is invalid or does not exist" : "Comprovació %s no és vàlida o no existeix",
    "Operation #%s does not exist" : "L\\'operació #%s no existeix",
    "Operation %s does not exist" : "L\\'operació %s no existeix",
    "Operation %s is invalid" : "L\\'operació %s no és vàlida",
    "Check %s does not exist" : "Comprovació %s no existeix",
    "Check %s is invalid" : "Comprovació %s no és vàlid",
    "Check #%s does not exist" : "Comprovació #%s no existeix",
    "Workflow" : "Flux de treball",
    "Files workflow engine" : "Fitxers del motor de flux de treball",
    "Open documentation" : "Obrir documentació",
    "Loading…" : "Carregant..."
},
"nplurals=2; plural=(n != 1);");
